@@ -13,7 +13,7 @@ echo "Testing with all features..."
 cargo test --release --lib --tests --features \
   "index-map network-logs pool-prefer-active enable-tls vendored-tls
   custom-reconnect-errors ignore-auth-error blocking-encoding full-tracing
-  reconnect-on-auth-error monitor metrics" \
+  reconnect-on-auth-error monitor metrics sentinel-client" \
   -- --test-threads=1
 
 echo "Testing with sentinel interface..."
